@@ -8,6 +8,7 @@ from matplotlib.ticker import FuncFormatter
 import pandas as pd
 import matplotlib.lines as lines
 import plotly.graph_objects as go
+from IPython.display import Image
 
 def pareto_graph(variable, salida='tabla'):
     #Ordenar en descendente y pasar a dataframe
@@ -98,9 +99,9 @@ def fis_tool_clean_df_columns(df):
     for col in df.columns:
         new_col = col.lower()
         new_col = new_col.replace(" ", "_")
-        new_col = new_col.replace("ó", "o")
+        new_col = new_col.replace("ó", "o").replace("ò","o")
         new_col = new_col.replace("í", "i").replace("á", "a").replace("é", "e")
-        new_col = new_col.replace("ü", "u")
+        new_col = new_col.replace("ü", "u").replace("à","a").replace("è","e")
         new_col = new_col.replace("(", "")
         new_col = new_col.replace(")", "")
         new_col = new_col.replace("-", "")
@@ -162,7 +163,8 @@ def fis_bs_histmax(df,value,labelx=None,labely=None,
 
 def fis_bs_waterfall(df,valor,group=False,group_value="",
                      Title="", x_lab="", y_lab="",
-                     formatting = "{:,.1f}", 
+                     formatting = "{:,.1f}",
+                     unidad = "",
                      green_color="#D6D7D9", 
                      red_color="#D6D7D9", 
                      blue_color="#364D6E",
@@ -303,10 +305,10 @@ def fis_bs_waterfall(df,valor,group=False,group_value="",
         # Determine if we want a neg or pos offset
         if row['amount'] > 0:
             y += (pos_offset*2)
-            plt.annotate(formatting.format(row['amount']),(loop,y),ha="center", fontsize=9)
+            plt.annotate(formatting.format(row['amount'])+"%s"%(unidad),(loop,y),ha="center", fontsize=10)
         else:
             y -= (pos_offset*4)
-            plt.annotate(formatting.format(row['amount']),(loop,y),ha="center", fontsize=9)
+            plt.annotate(formatting.format(row['amount'])+"%s"%(unidad),(loop,y),ha="center", fontsize=10)
         loop+=1
 
     #Scale up the y axis so there is room for the labels
@@ -324,7 +326,7 @@ def fis_bs_waterfall(df,valor,group=False,group_value="",
 
     return fig, ax
 
-def fis_bs_lollipop(df,valor1,valor2,figsize=(11,7),dpi=85,linewidth=5,size=10,textsize=12,offset=9,color='grey'):
+def fis_bs_lollipop(df,valor1,valor2,unidad="",figsize=(11,7),dpi=85,linewidth=5,size=10,textsize=12,offset=9,color='grey'):
     f, ax = plt.subplots(figsize=figsize,dpi=dpi)
     markers,stems,base = plt.stem(df[valor1],df[valor2])
     plt.setp(stems, 'linewidth', linewidth)
@@ -333,7 +335,7 @@ def fis_bs_lollipop(df,valor1,valor2,figsize=(11,7),dpi=85,linewidth=5,size=10,t
     xlocs, xlabs = plt.xticks()
     j = 0
     for v in df[valor2]:
-        plt.text(xlocs[j], v+offset, int(v), ha='center', fontsize=textsize)
+        plt.text(xlocs[j], v+offset, "%.2f %s"%(v,unidad), ha='center', fontsize=textsize)
         j+=1
     plt.ylabel("")
     plt.yticks([])                                    
